@@ -151,23 +151,26 @@ int dmonth(int month)
 
 uint32_t mosecs(void)
 {
-	struct tm *d;
+	struct tm d;
+#if defined(_SVID_SOURCE) || defined(_XOPEN_SOURCE) || defined(__linux__)
+	extern long timezone;
+#else
+	int timezone = 0;
+#endif
 
-	d = localtime(&data.month[0].month);
-
-	if (d == NULL) {
+	if (localtime_r(&data.month[0].month, &d) == NULL) {
 		return 0;
 	}
 
-	if (d->tm_mday < cfg.monthrotate) {
+	if (d.tm_mday < cfg.monthrotate) {
 		return 0;
 	}
 
-	d->tm_mday = cfg.monthrotate;
-	d->tm_hour = d->tm_min = d->tm_sec = 0;
+	d.tm_mday = cfg.monthrotate;
+	d.tm_hour = d.tm_min = d.tm_sec = 0;
 
 	if ((data.lastupdated-data.month[0].month)>0) {
-		return data.lastupdated-mktime(d);
+		return data.lastupdated-mktime(&d)+timezone;
 	} else {
 		return 0;
 	}
@@ -251,3 +254,16 @@ void panicexit(const char *sourcefile, const int sourceline)
 	printe(PT_Error);
 	exit(EXIT_FAILURE);
 }
+
+char *getversion(void)
+{
+	int i;
+	static char versionbuffer[16];
+	strncpy_nt(versionbuffer, VERSION, 16);
+	for (i=0; i<(int)strlen(versionbuffer); i++) {
+		if (versionbuffer[i] == '_') {
+			versionbuffer[i] = ' ';
+		}
+	}
+	return versionbuffer;
+}
