@@ -4,6 +4,7 @@
 typedef struct {
 	int running, updateinterval, dbcount, dodbsave, rundaemon;
 	int dbsaved, showhelp, sync, saveinterval, forcesave, noadd;
+	int alwaysadd;
 	uint32_t dbhash;
 	char cfgfile[512], dirname[512];
 	char user[33], group[33];
@@ -12,7 +13,7 @@ typedef struct {
 } DSTATE;
 
 void daemonize(void);
-int addinterfaces(const char *dirname);
+int addinterfaces(const char *dirname, const int running);
 void debugtimestamp(void);
 uid_t getuser(const char *user);
 gid_t getgroup(const char *group);
