@@ -16,5 +16,9 @@ char *getrateunit(int unit, int index);
 uint32_t getunitdivider(int unit, int index);
 char *getratestring(float rate, int len, int declen, int unit);
 int getpadding(int len, char *str);
+void cursortocolumn(int column);
+void cursorhide(void);
+void cursorshow(void);
+void eraseline(void);
 
 #endif
